@@ -14,19 +14,27 @@ from typing import Any
 
 from markdown import Markdown
 
-from markdown_exec.formatters.markdown import format_markdown
-from markdown_exec.formatters.pycon import format_pycon
-from markdown_exec.formatters.python import format_python
+from markdown_exec.formatters.bash import _format_bash  # noqa: WPS450
+from markdown_exec.formatters.console import _format_console  # noqa: WPS450
+from markdown_exec.formatters.markdown import _format_markdown  # noqa: WPS450
+from markdown_exec.formatters.pycon import _format_pycon  # noqa: WPS450
+from markdown_exec.formatters.python import _format_python  # noqa: WPS450
+from markdown_exec.formatters.sh import _format_sh  # noqa: WPS450
+from markdown_exec.formatters.tree import _format_tree  # noqa: WPS450
 
 __all__: list[str] = ["formatter", "validator"]  # noqa: WPS410
 
 
-_formatters = {
-    "md": format_markdown,
-    "markdown": format_markdown,
-    "py": format_python,
-    "python": format_python,
-    "pycon": format_pycon,
+formatters = {
+    "bash": _format_bash,
+    "console": _format_console,
+    "md": _format_markdown,
+    "markdown": _format_markdown,
+    "py": _format_python,
+    "python": _format_python,
+    "pycon": _format_pycon,
+    "sh": _format_sh,
+    "tree": _format_tree,
 }
 
 # negative look behind: matches only if | (pipe) if not preceded by \ (backslash)
@@ -49,15 +57,17 @@ def validator(
         Success or not.
     """
     exec_value = _to_bool(inputs.pop("exec", "no"))
-    if not exec_value:
+    if language != "tree" and not exec_value:
         return False
     html_value = _to_bool(inputs.pop("html", "no"))
     source_value = inputs.pop("source", "")
+    result_value = inputs.pop("result", "")
     tabs_value = inputs.pop("tabs", "Source|Result")
     tabs = tuple(_tabs_re.split(tabs_value, maxsplit=1))
     options["exec"] = exec_value
     options["html"] = html_value
     options["source"] = source_value
+    options["result"] = result_value
     options["tabs"] = tabs
     options["extra"] = inputs
     return True
@@ -91,8 +101,8 @@ def formatter(
     Returns:
         HTML contents.
     """
-    fmt = _formatters.get(language, lambda source, *args, **kwargs: source)
-    return fmt(source, md, **options)
+    fmt = formatters.get(language, lambda source, *args, **kwargs: source)
+    return fmt(source, md, **options)  # type: ignore[operator]
 
 
 falsy_values = {"", "no", "off", "false", "0"}
