@@ -8,31 +8,22 @@ from uuid import uuid4
 
 from markdown.core import Markdown
 
-from markdown_exec.formatters.python import run_python
-from markdown_exec.rendering import add_source, markdown
+from markdown_exec.formatters.python import _run_python  # noqa: WPS450
+from markdown_exec.logger import get_logger
+from markdown_exec.rendering import add_source, code_block, markdown
+
+logger = get_logger(__name__)
 
 
-def format_pycon(  # noqa: WPS231
+def _format_pycon(  # noqa: WPS231
     code: str,
     md: Markdown,
     html: bool,
     source: str,
+    result: str,
     tabs: tuple[str, str],
     **options: Any,
 ) -> str:
-    """Execute `pycon` code and return HTML.
-
-    Parameters:
-        code: The code to execute.
-        md: The Markdown instance.
-        html: Whether to inject output as HTML directly, without rendering.
-        source: Whether to show source as well, and where.
-        tabs: Titles of tabs (if used).
-        **options: Additional options passed from the formatter.
-
-    Returns:
-        HTML contents.
-    """
     markdown.setup(md)
 
     python_lines = []
@@ -42,12 +33,18 @@ def format_pycon(  # noqa: WPS231
     python_code = "\n".join(python_lines)
 
     extra = options.get("extra", {})
-    output = run_python(python_code, **extra)
+    try:
+        output = _run_python(python_code, **extra)
+    except RuntimeError as error:
+        logger.warning("Execution of pycon code block exited with non-zero status")
+        return markdown.convert(str(error))
     stash = {}
     if html:
         placeholder = str(uuid4())
         stash[placeholder] = output
         output = placeholder
+    elif result:
+        output = code_block(result, output)
     if source:
         source_code = textwrap.indent(python_code, ">>> ")
         output = add_source(source=source_code, location=source, output=output, language="pycon", tabs=tabs, **extra)
