@@ -43,6 +43,10 @@ def tabbed(*tabs: tuple[str, str]) -> str:
     return "\n".join(parts)
 
 
+def _hide_lines(source: str) -> str:
+    return "\n".join(line for line in source.split("\n") if "markdown-exec: hide" not in line).strip()
+
+
 def add_source(  # noqa: WPS212
     *,
     source: str,
@@ -68,6 +72,7 @@ def add_source(  # noqa: WPS212
     Returns:
         The updated output.
     """
+    source = _hide_lines(source)
     if location == "console":
         return code_block(language, source + "\n" + output, **extra)
 
@@ -146,7 +151,7 @@ class _MarkdownConverter:
         if not self._md_ref:
             self._md_ref = md
 
-    def convert(self, text: str, stash: dict[str, str]) -> Markup:
+    def convert(self, text: str, stash: dict[str, str] | None = None) -> Markup:
         """Convert Markdown text to safe HTML.
 
         Parameters:
@@ -171,7 +176,7 @@ class _MarkdownConverter:
             md.treeprocessors[_IdPrependingTreeprocessor.name].id_prefix = ""
 
         # restore html from stash
-        for placeholder, stashed in stash.items():
+        for placeholder, stashed in (stash or {}).items():
             converted = converted.replace(placeholder, stashed)
 
         return Markup(converted)
